# cvat-manifest-builder
## Installation & Use

```shell
# Install cvat-manifest-builder
> pip install cvat-manifest-builder

> cvat-manifest-builder --help
usage: cvat-manifest-builder [-h] --output_manifest_file OUTPUT_MANIFEST_FILE --input_data_path
                             INPUT_DATA_PATH

Builds a CVAT manifest file from a directory of images.

optional arguments:
  -h, --help            show this help message and exit
  --output_manifest_file OUTPUT_MANIFEST_FILE
                        Path to the output manifest file.
  --input_data_path INPUT_DATA_PATH
                        Path to the data directory.
```